@@ -56,8 +56,8 @@ class Client:
 		return self
 
 	async def close_session(self) -> None:
-		assert session is not None
-		await self.session.close()
+		if self.session is not None:
+			await self.session.close()
 
 	async def __aexit__(self, *args) -> None:
 		await self.close_session()
